use std::collections::HashMap;

mod source;
mod tests;

pub use source::*;

#[derive(Clone, Copy, Debug, Eq, PartialEq)]
pub enum Action {
    Block,
    Silence,
}

#[derive(Debug, Default, Eq, PartialEq)]
pub struct ActionTrust {
    pub block: u16,
    pub silence: u16,
}

impl ActionTrust {
    pub fn add_action(&mut self, action: Action, trust: u16) -> &mut Self {
        match action {
            Action::Block => self.block += trust,
            Action::Silence => self.silence += trust,
        }
        self
    }
}

impl From<(u16, u16)> for ActionTrust {
    fn from(value: (u16, u16)) -> Self {
        Self {
            block: value.0,
            silence: value.1,
        }
    }
}

#[derive(Debug, Default, Eq, PartialEq)]
pub struct ModerationList(pub HashMap<String, ActionTrust>);

impl ModerationList {
    pub fn add_source(&mut self, src: Source) -> &mut Self {
        let items = src.actions.into_iter();

        for (host, action) in items {
            let entry = self.0.entry(host).or_default();
            entry.add_action(action, src.trust);
        }

        self
    }
}
