use std::{collections::HashMap, fs};

use super::*;

#[derive(Debug, PartialEq, Eq)]
pub struct Source {
    pub actions: HashMap<String, Action>,
    pub trust: u16,
}

impl Default for Source {
    fn default() -> Self {
        Self {
            actions: HashMap::new(),
            trust: 100,
        }
    }
}

impl From<HashMap<String, Action>> for Source {
    fn from(map: HashMap<String, Action>) -> Self {
        Self {
            actions: map,
            trust: 100,
        }
    }
}

impl Source {
    pub fn build(map: HashMap<String, Action>, trust: u16) -> Self {
        let mut src = Self::from(map);
        src.trust = trust;
        src
    }

    pub fn add_from_file(&mut self, path: &str, action: Action) -> &mut Self {
        let contents = fs::read_to_string(path).unwrap();
        for host in contents.lines().filter(|line| !line.is_empty()) {
            self.add_action(host, action);
        }

        self
    }

    fn add_action(&mut self, host: &str, action: Action) -> &mut Self {
        self.actions.insert(host.to_string(), action);
        self
    }
}